Exception: Pdfh::ReDateError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/pdfh.rb

Overview

Regular Date Error, when there is not match

Instance Method Summary collapse

Constructor Details

#initialize(msg = "Date regular expression did not find a match in document.") ⇒ ReDateError

Parameters:

  • msg (String) (defaults to: "Date regular expression did not find a match in document.")


49
50
51
# File 'lib/pdfh.rb', line 49

def initialize(msg = "Date regular expression did not find a match in document.")
  super
end